==> xoops-2.4.5.tbz: www/xoops/htdocs/language/english/findusers.php <==
<?php
/*
 You may not change or alter any portion of this comment or credits
 of supporting developers from this source code or any supporting source code 
 which is considered copyrighted (c) material of the original comment or credit authors.
 
 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*/

/**
 *  Xoops Language
 *
 * @copyright       The XOOPS Project http://sourceforge.net/projects/xoops/
 * @license         http://www.fsf.org/copyleft/gpl.html GNU public license
 * @package         kernel
 * @subpackage      Xoops Find Users Language
 * @since           2.0.0
 * @author          Kazumi Ono <onokazu@xoops.org>
 * @version         $Id: findusers.php 3152 2009-04-18 13:30:57Z catzwolf $
 */
defined('XOOPS_ROOT_PATH') or die('Restricted access');

// _LANGCODE: en
// _CHARSET : UTF-8
// Translator: XOOPS Translation Team
define('_MA_USER_MORE', 'Search users');
define('_MA_USER_REMOVE', 'Remove unselected users');

//%%%%%%    File Name findusers.php     %%%%%
define('_MA_USER_ADD_SELECTED', 'Add selected users');
define('_MA_USER_GROUP', 'Group');
define('_MA_USER_LEVEL', 'Level');
define('_MA_USER_LEVEL_ACTIVE', 'Active');
define('_MA_USER_LEVEL_INACTIVE', 'Inactive');
define('_MA_USER_LEVEL_DISABLED', 'Disabled');
define('_MA_USER_RANK', 'Rank');
define('_MA_USER_FINDUS', 'Find Users');
define('_MA_USER_AVATAR', 'Avatar');
define('_MA_USER_REALNAME', 'Real Name');
define('_MA_USER_REGDATE', 'Joined Date');
define('_MA_USER_EMAIL', 'Email');
define('_MA_USER_PREVIOUS', 'Previous');
define('_MA_USER_NEXT', 'Next');
define('_MA_USER_USERSFOUND', '%s user(s) found');
define('_MA_USER_ACTUS', 'Active Users: %s');
define('_MA_USER_INACTUS', 'Inactive Users: %s');
define('_MA_USER_NOFOUND', 'No Users Found');
define('_MA_USER_UNAME', 'User Name');
define('_MA_USER_ICQ', 'ICQ Number');
define('_MA_USER_AIM', 'AIM Handle');
define('_MA_USER_YIM', 'YIM Handle');
define('_MA_USER_MSNM', 'MSNM Handle');
define('_MA_USER_LOCATION', 'Location contains');
define('_MA_USER_OCCUPATION', 'Occupation contains');
define('_MA_USER_INTEREST', 'Interest contains');
define('_MA_USER_URLC', 'URL contains');
define('_MA_USER_SORT', 'Sort by');
define('_MA_USER_ORDER', 'Order');
define('_MA_USER_LASTLOGIN', 'Last login');
define('_MA_USER_POSTS', 'Number of posts');
define('_MA_USER_ASC', 'Ascending order');
define('_MA_USER_DESC', 'Descending order');
define('_MA_USER_LIMIT', 'Number of users per page');
define('_MA_USER_RESULTS', 'Search results');
define('_MA_USER_SHOWMAILOK', 'Type of users to show');
define('_MA_USER_MAILOK', 'Only users that accept mail');
define('_MA_USER_MAILNG', 'Only users that don\'t accept mail');
define('_MA_USER_BOTH', 'All');
define('_MA_USER_RANGE_LAST_LOGIN', 'Logged in past <span style=\'color:#ff0000;\'>X</span>days');
define('_MA_USER_RANGE_USER_REGDATE', 'Registered in past <span style=\'color:#ff0000;\'>X</span>days');
define('_MA_USER_RANGE_POSTS', 'Posts');
define('_MA_USER_HASAVATAR', 'Has avatar');
define('_MA_USER_MODE_SIMPLE', 'Simple mode');
define('_MA_USER_MODE_ADVANCED', 'Advanced mode');
define('_MA_USER_MODE_QUERY', 'Query mode');
define('_MA_USER_QUERY', 'Query');
define('_MA_USER_SEARCHAGAIN', 'Search again');
define('_MA_USER_NOUSERSELECTED', 'No user selected');
define('_MA_USER_USERADDED', 'Users have been added');
define('_MA_USER_SENDMAIL', 'Send Email');

?>

==> xoops-2.5.5.tbz: www/xoops/htdocs/language/english/findusers.php <==
<?php
// $Id: findusers.php 8066 2011-11-06 05:09:33Z beckmi $
// _LANGCODE: en
// _CHARSET : UTF-8
// Translator: XOOPS Translation Team
define('_MA_USER_MORE', 'Search users');
define('_MA_USER_REMOVE', 'Remove unselected users');

//%%%%%%    File Name findusers.php     %%%%%
define('_MA_USER_ADD_SELECTED', 'Add selected users');
define('_MA_USER_GROUP', 'Group');
define('_MA_USER_LEVEL', 'Level');
define('_MA_USER_LEVEL_ACTIVE', 'Active');
define('_MA_USER_LEVEL_INACTIVE', 'Inactive');
define('_MA_USER_LEVEL_DISABLED', 'Disabled');
define('_MA_USER_RANK', 'Rank');
define('_MA_USER_FINDUS', 'Find Users');
define('_MA_USER_AVATAR', 'Avatar');
define('_MA_USER_REALNAME', 'Real Name');
define('_MA_USER_REGDATE', 'Joined Date');
define('_MA_USER_EMAIL', 'Email');
define('_MA_USER_PREVIOUS', 'Previous');
define('_MA_USER_NEXT', 'Next');
define('_MA_USER_USERSFOUND', '%s user(s) found');
define('_MA_USER_ACTUS', 'Active Users: %s');
define('_MA_USER_INACTUS', 'Inactive Users: %s');
define('_MA_USER_NOFOUND', 'No Users Found');
define('_MA_USER_UNAME', 'User Name');
define('_MA_USER_ICQ', 'ICQ Number');
define('_MA_USER_AIM', 'AIM Handle');
define('_MA_USER_YIM', 'YIM Link');
define('_MA_USER_MSNM', 'MSNM Link');
define('_MA_USER_LOCATION', 'Location contains');
define('_MA_USER_OCCUPATION', 'Occupation contains');
define('_MA_USER_INTEREST', 'Interest contains');
define('_MA_USER_URLC', 'URL contains');
define('_MA_USER_SORT', 'Sort by');
define('_MA_USER_ORDER', 'Order');
define('_MA_USER_LASTLOGIN', 'Last login');
define('_MA_USER_POSTS', 'Number of posts');
define('_MA_USER_ASC', 'Ascending order');
define('_MA_USER_DESC', 'Descending order');
define('_MA_USER_LIMIT', 'Number of users per page');
define('_MA_USER_RESULTS', 'Search results');
define('_MA_USER_SHOWMAILOK', 'Type of users to show');
define('_MA_USER_MAILOK', 'Only users that accept email');
define('_MA_USER_MAILNG', 'Only users that don\'t accept email');
define('_MA_USER_BOTH', 'All');
define('_MA_USER_RANGE_LAST_LOGIN', 'Logged in past <span style=\'color:#ff0000;\'>X</span>days');
define('_MA_USER_RANGE_USER_REGDATE', 'Registered in past <span style=\'color:#ff0000;\'>X</span>days');
define('_MA_USER_RANGE_POSTS', 'Posts');
define('_MA_USER_HASAVATAR', 'Has avatar');
define('_MA_USER_MODE_SIMPLE', 'Simple mode');
define('_MA_USER_MODE_ADVANCED', 'Advanced mode');
define('_MA_USER_MODE_QUERY', 'Query mode');
define('_MA_USER_QUERY', 'Query');
define('_MA_USER_SEARCHAGAIN', 'Search again');
define('_MA_USER_NOUSERSELECTED', 'No user selected');
define('_MA_USER_USERADDED', 'Users have been added');
define('_MA_USER_SENDMAIL', 'Send Email');

//2.5.4
define('_MA_USER_FACEBOOK', 'Facebook Link'); //TO DO
define('_MA_USER_SKYPE', 'Skype Link');//TO DO
?>
